==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebInputDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentValueChangedEventArgsDescriptionMetadata } from "./WebComponentValueChangedEventArgsDescriptionMetadata";
import { WebInputBaseDescriptionMetadata } from "./WebInputBaseDescriptionMetadata";
import { WebInputDescription } from "./WebInputDescription";
/**
 * @hidden
 */
var WebInputDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebInputDescriptionMetadata, _super);
    function WebInputDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebInputDescriptionMetadata.b = function (a) {
        if (WebInputDescriptionMetadata.a == null) {
            WebInputDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebInputDescriptionMetadata.c(WebInputDescriptionMetadata.a);
        }
        if (a.k(WebInputDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebInputDescriptionMetadata.a);
        WebComponentValueChangedEventArgsDescriptionMetadata.d(a);
    };
    WebInputDescriptionMetadata.c = function (a) {
        WebInputBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Input");
        a.item("__tagNameWC", "String:igc-input");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Value", "String");
        a.item("DisplayType", "(wc:Type)ExportedType:string:InputType");
        a.item("DisplayType@stringUnion", "WebComponents;React");
        a.item("DisplayType@names", "Number;Email;Password;Search;Tel;Text;Url");
        a.item("Inputmode", "ExportedType:string:InputInputmode");
        a.item("Inputmode@stringUnion", "WebComponents;React");
        a.item("Inputmode@names", "None;Email;Search;Tel;Url;Txt;Decimal;Numeric");
        a.item("Pattern", "String");
        a.item("Invalid", "Boolean");
        a.item("Minlength", "Number:double");
        a.item("Maxlength", "Number:double");
        a.item("Min", "String");
        a.item("Max", "String");
        a.item("Step", "Number:double");
        a.item("Autofocus", "Boolean");
        a.item("Autocomplete", "String");
        a.item("TabIndex", "Number:double");
        a.item("ChangeRef", "EventRef::change");
    };
    WebInputDescriptionMetadata.d = function (a) {
        WebInputDescriptionMetadata.b(a);
        a.ad("WebInput", function () { return new WebInputDescription(); });
        a.ac("WebInput", WebInputDescriptionMetadata.a);
    };
    WebInputDescriptionMetadata.$t = markType(WebInputDescriptionMetadata, 'WebInputDescriptionMetadata');
    WebInputDescriptionMetadata.a = null;
    return WebInputDescriptionMetadata;
}(Base));
export { WebInputDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebInputDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentDataValueChangedEventArgsDescriptionMetadata } from "./WebComponentDataValueChangedEventArgsDescriptionMetadata";
import { WebInputBaseDescriptionMetadata } from "./WebInputBaseDescriptionMetadata";
import { WebInputDescription } from "./WebInputDescription";
/**
 * @hidden
 */
var WebInputDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebInputDescriptionMetadata, _super);
    function WebInputDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebInputDescriptionMetadata.b = function (a) {
        if (WebInputDescriptionMetadata.a == null) {
            WebInputDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebInputDescriptionMetadata.c(WebInputDescriptionMetadata.a);
        }
        if (a.k(WebInputDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebInputDescriptionMetadata.a);
        WebComponentDataValueChangedEventArgsDescriptionMetadata.d(a);
    };
    WebInputDescriptionMetadata.c = function (a) {
        WebInputBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Input");
        a.item("__tagNameWC", "String:igc-input");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("ValueRef", "(w:Value,wf:Value)DataRef");
        a.item("DisplayType", "(wc:Type)ExportedType:string:InputType");
        a.item("DisplayType@stringUnion", "WebComponents;React");
        a.item("DisplayType@names", "Number;Email;Password;Search;Tel;Text;Url");
        a.item("InputMode", "String");
        a.item("Pattern", "String");
        a.item("MinLength", "Number:double");
        a.item("MaxLength", "Number:double");
        a.item("Min", "String");
        a.item("Max", "String");
        a.item("Step", "Number:double");
        a.item("Autofocus", "Boolean");
        a.item("Autocomplete", "String");
        a.item("ValidateOnly", "Boolean");
        a.item("ChangeRef", "EventRef::change");
    };
    WebInputDescriptionMetadata.d = function (a) {
        WebInputDescriptionMetadata.b(a);
        a.ae("WebInput", function () { return new WebInputDescription(); });
        a.ad("WebInput", WebInputDescriptionMetadata.a);
    };
    WebInputDescriptionMetadata.$t = markType(WebInputDescriptionMetadata, 'WebInputDescriptionMetadata');
    WebInputDescriptionMetadata.a = null;
    return WebInputDescriptionMetadata;
}(Base));
export { WebInputDescriptionMetadata };
